@@ -5,8 +5,8 @@
 #                       Any changes made without RCS will be lost
 #
 #              $Source: /usr/local/cvsroot/vbtk/VBTK/Controller.pm,v $
-#            $Revision: 1.9 $
-#                $Date: 2002/02/13 07:38:15 $
+#            $Revision: 1.12 $
+#                $Date: 2002/03/04 20:53:06 $
 #              $Author: bhenry $
 #              $Locker:  $
 #               $State: Exp $
@@ -32,6 +32,15 @@
 #       REVISION HISTORY:
 #
 #       $Log: Controller.pm,v $
+#       Revision 1.12  2002/03/04 20:53:06  bhenry
+#       *** empty log message ***
+#
+#       Revision 1.11  2002/03/04 16:49:09  bhenry
+#       Changed requirement back to perl 5.6.0
+#
+#       Revision 1.10  2002/03/02 00:53:54  bhenry
+#       Documentation updates
+#
 #       Revision 1.9  2002/02/13 07:38:15  bhenry
 #       Moved write_pid_file functionality from Common into Controller
 #
@@ -50,7 +59,7 @@
 
 package VBTK::Controller;
 
-use 5.6.1;
+use 5.6.0;
 use strict;
 use warnings;
 # I like using undef as a value so I'm turning off the uninitialized warnings
@@ -470,16 +479,6 @@ __END__
 
 VBTK::Controller - VBTK Master Controller Package
 
-=head1 SUPPORTED PLATFORMS
-
-=over 4
-
-=item * 
-
-Solaris
-
-=back
-
 =head1 SYNOPSIS
 
   use VBTK::Controller;
@@ -577,8 +576,11 @@ $VBCONF directory.
 
 =head1 SEE ALSO
 
-L<VBTK|VBTK>,
-L<VBTK::Server|VBTK::Server>
+=over 4
+
+=item L<VBTK|VBTK>
+
+=item L<VBTK::Server|VBTK::Server>
 
 =back
 
