@@ -5,8 +5,8 @@
 #                       Any changes made without RCS will be lost
 #
 #              $Source: /usr/local/cvsroot/vbtk/VBTK/DBI.pm,v $
-#            $Revision: 1.5 $
-#                $Date: 2002/02/13 07:38:52 $
+#            $Revision: 1.8 $
+#                $Date: 2002/03/04 20:53:06 $
 #              $Author: bhenry $
 #              $Locker:  $
 #               $State: Exp $
@@ -41,6 +41,15 @@
 #       REVISION HISTORY:
 #
 #       $Log: DBI.pm,v $
+#       Revision 1.8  2002/03/04 20:53:06  bhenry
+#       *** empty log message ***
+#
+#       Revision 1.7  2002/03/04 16:49:09  bhenry
+#       Changed requirement back to perl 5.6.0
+#
+#       Revision 1.6  2002/03/02 00:53:54  bhenry
+#       Documentation updates
+#
 #       Revision 1.5  2002/02/13 07:38:52  bhenry
 #       Disabled RrdLogRecovery and removed use of @log
 #
@@ -54,7 +63,7 @@
 
 package VBTK::DBI;
 
-use 5.6.1;
+use 5.6.0;
 use strict;
 use warnings;
 # I like using undef as a value so I'm turning off the uninitialized warnings
@@ -319,16 +328,6 @@ __END__
 
 VBTK::Http - Database Monitoring
 
-=head1 SUPPORTED PLATFORMS
-
-=over 4
-
-=item * 
-
-Solaris
-
-=back
-
 =head1 SYNOPSIS
 
   $d = new VBTK::DBI (
