@@ -4,8 +4,8 @@
 #                       Any changes made without RCS will be lost
 #
 #              $Source: /usr/local/cvsroot/vbtk/VBTK/Snmp.pm,v $
-#            $Revision: 1.7 $
-#                $Date: 2002/02/13 07:38:51 $
+#            $Revision: 1.11 $
+#                $Date: 2002/03/04 20:53:07 $
 #              $Author: bhenry $
 #              $Locker:  $
 #               $State: Exp $
@@ -36,6 +36,18 @@
 #       REVISION HISTORY:
 #
 #       $Log: Snmp.pm,v $
+#       Revision 1.11  2002/03/04 20:53:07  bhenry
+#       *** empty log message ***
+#
+#       Revision 1.10  2002/03/04 16:49:09  bhenry
+#       Changed requirement back to perl 5.6.0
+#
+#       Revision 1.9  2002/03/02 00:53:55  bhenry
+#       Documentation updates
+#
+#       Revision 1.8  2002/02/19 19:10:42  bhenry
+#       *** empty log message ***
+#
 #       Revision 1.7  2002/02/13 07:38:51  bhenry
 #       Disabled RrdLogRecovery and removed use of @log
 #
@@ -55,7 +67,7 @@
 
 package VBTK::Snmp;
 
-use 5.6.1;
+use 5.6.0;
 use strict;
 use warnings;
 # I like using undef as a value so I'm turning off the uninitialized warnings
@@ -65,6 +77,7 @@ use VBTK;
 use VBTK::Common;
 use VBTK::Parser;
 use SNMP;
+use Storable qw(dclone);
 
 #$SNMP::debugging = 3;
 #$SNMP::auto_init_mib = 0;
@@ -206,7 +219,6 @@ sub run
     my $snmpSession   = $self->{snmpSession};
     my $Labels        = $self->{Labels};
     my $Interval      = $self->{Interval};
-    my $lastTime      = $self->{lastTime};
     my $GetMultRows   = $self->{GetMultRows};
     my $ErrorStatus   = $self->{ErrorStatus};
     my $Host      = $self->{Host};
@@ -299,16 +311,6 @@ __END__
 
 VBTK::Snmp - Snmp monitoring.
 
-=head1 SUPPORTED PLATFORMS
-
-=over 4
-
-=item * 
-
-Solaris
-
-=back
-
 =head1 SYNOPSIS
 
   $stdHeader = 
